NotifyMode

Enum NotifyMode 

pub enum NotifyMode {
    Disabled,
    Monitor,
    Virtualize,
}
Seccomp user notification mode.

Controls how the supervisor handles intercepted syscalls from the sandboxed child.

Variants



Disabled

No seccomp notify filter installed. Zero overhead. Default.



Monitor

Supervisor logs syscalls and returns SECCOMP_USER_NOTIF_FLAG_CONTINUE. Minimal overhead. For debugging/auditing.



Virtualize

Supervisor intercepts FS syscalls, translates paths via VirtualFs, opens files at translated paths, injects fd via SECCOMP_IOCTL_NOTIF_ADDFD.